@@ -1,5 +1,5 @@
 /* Battle Tanks Game
- * Copyright (C) 2006-2007 Battle Tanks team
+ * Copyright (C) 2006-2008 Battle Tanks team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,6 +16,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+/* 
+ * Additional rights can be granted beyond the GNU General Public License 
+ * on the terms provided in the Exception. If you modify this file, 
+ * you may extend this exception to your version of the file, 
+ * but you are not obligated to do so. If you do not wish to provide this
+ * exception without modification, you must delete this exception statement
+ * from your version and license this file solely under the GPL without exception. 
+*/
+
 #include "object.h"
 
 class DestructableObject : public Object {
@@ -24,13 +33,17 @@ public:
 
 	virtual Object * clone() const;
 	virtual void tick(const float dt);
-	virtual void onSpawn();
-	virtual void addDamage(Object *from, const int hp, const bool emitDeath = true);
+	virtual void on_spawn();
+	virtual void add_damage(Object *from, const int hp, const bool emitDeath = true);
 	virtual void onBreak();
 
 	virtual void serialize(mrt::Serializator &s) const;
 	virtual void deserialize(const mrt::Serializator &s);
 
+	virtual void emit(const std::string &event, Object * emitter = NULL);
+
+	void destroy();
+
 protected:
 	bool _broken;
 	Alarm _respawn;
